@@ -104,7 +104,11 @@ if (!array_key_exists($page, $allowed_pages)) {
 
 ?>
 <!DOCTYPE html>
-<html lang="en">
+<html lang="en" data-theme="<?php
+    $theme_pref = $_SESSION['theme_preference'] ?? 'auto';
+    // Convert 'auto' to actual theme based on time or just default to dark
+    echo ($theme_pref === 'auto') ? 'dark' : htmlspecialchars($theme_pref);
+?>">
     <head>
         <meta charset="utf-8">
         <meta http-equiv="X-UA-Compatible" content="IE=edge">
@@ -157,6 +161,30 @@ if (!array_key_exists($page, $allowed_pages)) {
                 
                 <!-- User Dropdown -->
                 <div class="navbar-nav ms-auto">
+                    <!-- Theme Toggle Switch -->
+                    <div class="font-size-toggle-wrapper">
+                        <label class="font-size-toggle-label" for="themeToggle">
+                            <span class="font-size-icons">
+                                <i class="fa fa-sun-o" id="lightThemeIcon"></i>
+                                <i class="fa fa-moon-o" id="darkThemeIcon"></i>
+                            </span>
+                            <div class="toggle-switch" title="Toggle light/dark theme">
+                                <input type="checkbox"
+                                       id="themeToggle"
+                                       <?php
+                                       $theme_pref = $_SESSION['theme_preference'] ?? 'auto';
+                                       // If theme is light or auto (detected as light), check the toggle
+                                       echo ($theme_pref === 'dark') ? '' : 'checked';
+                                       ?>
+                                       aria-label="Toggle light/dark theme"
+                                       aria-describedby="themeToggleDescription"
+                                       role="switch">
+                                <span class="toggle-slider"></span>
+                            </div>
+                            <span class="visually-hidden" id="themeToggleDescription">Toggle between light and dark theme</span>
+                        </label>
+                    </div>
+
                     <!-- Font Size Toggle Switch -->
                     <div class="font-size-toggle-wrapper">
                         <label class="font-size-toggle-label" for="fontSizeToggle">
@@ -434,6 +462,83 @@ if (!array_key_exists($page, $allowed_pages)) {
                     .catch(error => console.error('Error toggling font size:', error));
                 });
             }
+
+            // Theme Toggle Functionality
+            const themeToggle = document.getElementById('themeToggle');
+            if (themeToggle) {
+                // Function to apply theme
+                function applyTheme(theme) {
+                    const html = document.documentElement;
+
+                    // Handle auto theme - detect system preference
+                    if (theme === 'auto') {
+                        const prefersDark = window.matchMedia('(prefers-color-scheme: dark)').matches;
+                        theme = prefersDark ? 'dark' : 'light';
+                    }
+
+                    // Apply theme attribute
+                    html.setAttribute('data-theme', theme);
+
+                    // Update toggle state (checked = light, unchecked = dark)
+                    themeToggle.checked = (theme === 'light');
+                }
+
+                // Apply initial theme on page load
+                const initialTheme = html.getAttribute('data-theme') || 'dark';
+                applyTheme(initialTheme);
+
+                // Listen for system theme changes if using auto mode
+                window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', (e) => {
+                    const currentPref = '<?php echo $_SESSION['theme_preference'] ?? 'auto'; ?>';
+                    if (currentPref === 'auto') {
+                        applyTheme('auto');
+                    }
+                });
+
+                // Handle toggle change
+                themeToggle.addEventListener('change', function() {
+                    const isLight = this.checked;
+                    const newTheme = isLight ? 'light' : 'dark';
+
+                    // Apply theme immediately for smooth transition
+                    document.documentElement.setAttribute('data-theme', newTheme);
+
+                    // Send AJAX request to save preference
+                    fetch('api/theme-toggle.php', {
+                        method: 'POST',
+                        headers: {
+                            'Content-Type': 'application/x-www-form-urlencoded',
+                            'X-CSRF-Token': '<?php echo get_csrf_token(); ?>'
+                        },
+                        body: 'action=set&theme=' + newTheme
+                    })
+                    .then(response => response.json())
+                    .then(data => {
+                        if (data.success) {
+                            // Update aria-checked for screen readers
+                            themeToggle.setAttribute('aria-checked', isLight ? 'true' : 'false');
+
+                            // Announce change to screen readers
+                            const announcement = document.createElement('div');
+                            announcement.setAttribute('role', 'status');
+                            announcement.setAttribute('aria-live', 'polite');
+                            announcement.className = 'visually-hidden';
+                            announcement.textContent = isLight ? 'Light theme enabled' : 'Dark theme enabled';
+                            document.body.appendChild(announcement);
+                            setTimeout(() => announcement.remove(), 1000);
+                        } else {
+                            // Revert on error
+                            applyTheme(newTheme === 'light' ? 'dark' : 'light');
+                            console.error('Failed to save theme preference:', data.error);
+                        }
+                    })
+                    .catch(error => {
+                        console.error('Error toggling theme:', error);
+                        // Revert on error
+                        applyTheme(newTheme === 'light' ? 'dark' : 'light');
+                    });
+                });
+            }
         });
         </script>
     </body>
